Total copy number per 500kb bin per cell, as produced by the HMMcopy step of the DLP+ pipeline. Covers three OV2295-derived cell lines: SA921 (85 cells), SA1090 (110) and SA922 (55).

CNbins

Format

A data frame with 1,093,750 rows and 7 columns:

chr, start, end

genomic bin

reads

reads in the bin

copy

normalised read depth

state

total copy number

cell_id

cell identifier, {sample}-{library}-R{row}-C{column}

Details

This is the format the copy number functions expect: chr, start, end, cell_id, state (total copy number) and copy (normalised read depth).