Sparse gene-by-cell counts matrix for 10x scRNA-seq of the OV2295 lines, used in the allele specific copy number from RNA vignette.

countsmatrix

Format

A dgCMatrix with 21,175 genes (rows) and 814 cells (columns). Row names are gene symbols, column names are {patient}-{sample}_{lane}_{barcode}.